RuntimeSessionExt

Trait RuntimeSessionExt 

pub trait RuntimeSessionExt: SessionExt {
    // Provided methods
    fn handle(&self) -> Handle { ... }
    fn with_tokio(self) -> Self { ... }
    fn with_handle(self, handle: Handle) -> Self { ... }
}
Extension trait for accessing runtime session data.

Provided Methods

fn handle(&self) -> Handle

Returns a handle for this session’s runtime.

fn with_tokio(self) -> Self

Configure the runtime session to use the application’s Tokio runtime.

For example, if the application is launched using #[tokio::main].

fn with_handle(self, handle: Handle) -> Self

Configure the runtime session to use a specific Vortex runtime handle.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors