Module std_file

Module std_file 

Structs

FileReadAt
An adapter type wrapping a File to implement VortexReadAt.

Constants

DEFAULT_CONCURRENCY
Default number of concurrent requests to allow for local file I/O.

Functions

read_exact_at
Read exactly buffer.len() bytes from file starting at offset. This is a platform-specific helper that uses the most efficient method available.