AbortHandle

Trait AbortHandle 

pub trait AbortHandle: Send + Sync {
    // Required method
    fn abort(self: Box<Self>);
}
A handle that may be used to optimistically abort a spawned task.

If dropped, the task should continue to completion. If explicitly aborted, the task should be cancelled if it has not yet started executing.

Required Methods

fn abort(self: Box<Self>)

Implementations on Foreign Types

Source

impl AbortHandle for AbortHandle

Source

fn abort(self: Box<Self>)

Implementors