pub trait AbortHandle: Send + Sync {
// Required method
fn abort(self: Box<Self>);
}Expand description
A handle that may be used to optimistically abort a spawned task.
If dropped, the task should continue to completion. If explicitly aborted, the task should be cancelled if it has not yet started executing.