Structs
- File
Read At - An adapter type wrapping a
Fileto implementVortexReadAt.
Constants
- DEFAULT_
CONCURRENCY - Default number of concurrent requests to allow for local file I/O.
Functions
- read_
exact_ at - Read exactly
buffer.len()bytes fromfilestarting atoffset. This is a platform-specific helper that uses the most efficient method available.